Module retry

Module retry 

Structs

RetryAction
The action a RetryStrategy returns to indicate when to retry.
RetryManager
RetryRequest
Metadata about a request that is being considered for retry.

Enums

RetryReason
The reason an operation is being retried.

Traits

RetryStrategy
A strategy that decides whether and when to retry a failed operation.