pub struct RetryRequest {
pub is_idempotent: bool,
pub retry_attempts: u32,
pub retry_reasons: HashSet<RetryReason>,
/* private fields */
}Expand description
Metadata about a request that is being considered for retry.
Fields
is_idempotent: boolWhether the operation is idempotent (safe to retry without side effects).
retry_attempts: u32The number of retry attempts that have already been made.
retry_reasons: HashSet<RetryReason>The set of reasons this request has been retried so far.
Implementations
Sourceimpl RetryRequest
impl RetryRequest
pub fn is_idempotent(&self) -> bool
pub fn retry_attempts(&self) -> u32
pub fn retry_reasons(&self) -> &HashSet<RetryReason>