pub struct ExponentialBackoffCalculator { /* private fields */ }Expand description
An exponential backoff calculator that increases the delay between retries exponentially, clamped between a minimum and maximum duration.
The backoff for attempt n is calculated as:
clamp(min * backoff_factor ^ n, min, max)Defaults
| Parameter | Default |
|---|---|
min | 1 ms |
max | 1000 ms |
backoff_factor | 2.0 |
Example
use couchbase_core::retrybesteffort::{BestEffortRetryStrategy, ExponentialBackoffCalculator};
use std::time::Duration;
use std::sync::Arc;
let calc = ExponentialBackoffCalculator::new(
Duration::from_millis(5), // min
Duration::from_millis(500), // max
2.0, // backoff_factor
);
let strategy = Arc::new(BestEffortRetryStrategy::new(calc));Implementations