Structs
- Retry
Action - The action a
RetryStrategyreturns to indicate when to retry. - Retry
Manager - Retry
Request - Metadata about a request that is being considered for retry.
Enums
- Retry
Reason - The reason an operation is being retried.
Traits
- Retry
Strategy - A strategy that decides whether and when to retry a failed operation.